@@ -162,10 +162,11 @@ def main(testing=False, coverage_testing=False):
         cov.stop()
         cov.save()
         cov.combine()
+        cov.save()
         cov.report(file=stream, omit=omit)
     return(int(not result.wasSuccessful()))
 
 
 
 if __name__ == '__main__': # pragma: no cover
-    main()
+    sys.exit(main())
